// Copyright (c) 2024 Celestino Amoroso (celestino.amoroso@gmail.com).
// All rights reserved.

// builtin-fmt.go
package expr

import "fmt"

func printFunc(ctx ExprContext, name string, args []any) (result any, err error) {
	var n int
	if n, err = fmt.Print(args...); err == nil {
		result = int64(n)
	}
	return
}

func printLnFunc(ctx ExprContext, name string, args []any) (result any, err error) {
	var n int
	if n, err = fmt.Println(args...); err == nil {
		result = int64(n)
	}
	return
}

func ImportFmtFuncs(ctx ExprContext) {
	ctx.RegisterFunc("print", NewGolangFunctor(printFunc), TypeInt, []ExprFuncParam{
		NewFuncParamFlag(ParamItem, PfRepeat),
	})
	ctx.RegisterFunc("println", NewGolangFunctor(printLnFunc), TypeInt, []ExprFuncParam{
		NewFuncParamFlag(ParamItem, PfRepeat),
	})
}

func init() {
	RegisterBuiltinModule("fmt", ImportFmtFuncs, "String and console formatting functions")
}
